﻿using System;
using System.Web.UI;
using System.Web.UI.WebControls;
using umbraco.DataLayer;
using umbraco.cms.businesslogic.datatype;
using umbraco.BusinessLogic;

namespace Mindbus
{
  public class DropDownPrevalueEditor : System.Web.UI.WebControls.PlaceHolder, umbraco.interfaces.IDataPrevalue
  {
    #region IDataPrevalue Members

    // referenced datatype
    private umbraco.cms.businesslogic.datatype.BaseDataType _datatype;

    private TextBox _txtQuery;
    private DropDownList _ddlDBType;

    public DropDownPrevalueEditor(umbraco.cms.businesslogic.datatype.BaseDataType DataType)
    {
      _datatype = DataType;
      setupChildControls();
    }

    private void setupChildControls()
    {
      _txtQuery = new TextBox();
      _txtQuery.ID = "txtQuery";
      _txtQuery.CssClass = "umbEditorTextField";

      _ddlDBType = new DropDownList();
      _ddlDBType.ID = "ddlDBType";
      _ddlDBType.Items.Add(new ListItem() { Value = ((int)DBTypes.Integer).ToString() , Text = DBTypes.Integer.ToString() });
      _ddlDBType.Items.Add(new ListItem() { Value = ((int)DBTypes.Date).ToString(), Text = DBTypes.Date.ToString() });
      _ddlDBType.Items.Add(new ListItem() { Value = ((int)DBTypes.Ntext).ToString(), Text = DBTypes.Ntext.ToString() });
      _ddlDBType.Items.Add(new ListItem() { Value = ((int)DBTypes.Nvarchar).ToString(), Text = DBTypes.Nvarchar.ToString() }); 

      Controls.Add(_txtQuery);
      Controls.Add(_ddlDBType);
    }

    public Control Editor
    {
      get { return this; }
    }

    protected override void OnLoad(EventArgs e)
    {
      base.OnLoad(e);
      if (!Page.IsPostBack)
      {
        if (Configuration.Length > 0)
        {
          _txtQuery.Text = Configuration;
        }
        else
        {
          _txtQuery.Text = "";
        }

        _ddlDBType.SelectedValue = ((int)_datatype.DBType).ToString();
      }
    }

    public void Save()
    {
      //_datatype.DBType = (umbraco.cms.businesslogic.datatype.DBTypes)Enum.Parse(typeof(umbraco.cms.businesslogic.datatype.DBTypes), DBTypes.Ntext.ToString(), true);
      _datatype.DBType = (umbraco.cms.businesslogic.datatype.DBTypes)Enum.Parse(typeof(umbraco.cms.businesslogic.datatype.DBTypes), _ddlDBType.SelectedItem.Text, true);

      string data = _txtQuery.Text;

      SqlHelper.ExecuteNonQuery("delete from cmsDataTypePreValues where datatypenodeid = @dtdefid",
              SqlHelper.CreateParameter("@dtdefid", _datatype.DataTypeDefinitionId));
      SqlHelper.ExecuteNonQuery("insert into cmsDataTypePreValues (datatypenodeid,[value],sortorder,alias) values (@dtdefid,@value,0, '" + _datatype.DataTypeName + "')",
            SqlHelper.CreateParameter("@dtdefid", _datatype.DataTypeDefinitionId), SqlHelper.CreateParameter("@value", data));

    }

    protected override void Render(HtmlTextWriter writer)
    {
      writer.WriteLine("<table>");
      writer.Write("<tr><th>Sql Query:</th><td>");
      _txtQuery.RenderControl(writer);
      writer.Write("</td></tr>");

      writer.Write("<tr><th>Database Type:</th><td>");
      _ddlDBType.RenderControl(writer);
      writer.Write("</td></tr>");

      writer.Write("<tr><td colspan='2' class='propertypaneTitel'>Example: SELECT ID, Name FROM table ORDER BY Name<td></tr>");
      writer.Write("<tr><td colspan='2' class='propertypaneTitel'>The first <b>column is the value</b> and the <b>second one is the text</b>. If there's only one column it will be used for both text and value.<td></tr>");

      writer.Write("<tr><td colspan='2' class='propertypaneTitel'>The value is stored in cmspropertyData.<td></tr>");
      writer.Write("</table>");

    }

    public string Configuration
    {
      get
      {
        object conf =
           SqlHelper.ExecuteScalar<object>("select value from cmsDataTypePreValues where datatypenodeid = @datatypenodeid",
                                   SqlHelper.CreateParameter("@datatypenodeid", _datatype.DataTypeDefinitionId));

        if (conf != null)
          return conf.ToString();
        else
          return "";
      }
    }

    #endregion

    public static ISqlHelper SqlHelper
    {
      get
      {
        return Application.SqlHelper;
      }
    }
  }
}
